@@ -5,9 +5,9 @@ Created on Fri Oct 04 13:19:01 2013
 
 Author: Josef Perktold
 """
-from __future__ import print_function
 from statsmodels.compat.python import lrange, lmap
 
+import os
 import copy
 
 import pytest
@@ -15,19 +15,15 @@ import numpy as np
 from numpy.testing import assert_allclose, assert_equal
 import pandas as pd
 
-from statsmodels import iolib
 from statsmodels.tools.tools import add_constant
 from statsmodels.regression.linear_model import OLS
 import statsmodels.sandbox.regression.gmm as gmm
 
 
 def get_griliches76_data():
-    import os
     curdir = os.path.split(__file__)[0]
     path = os.path.join(curdir, 'griliches76.dta')
-    with pytest.warns(FutureWarning):
-        griliches76_data = iolib.genfromdta(path, missing_flt=np.NaN,
-                                            pandas=True)
+    griliches76_data = pd.read_stata(path)
 
     # create year dummies
     years = griliches76_data['year'].unique()
@@ -190,10 +186,11 @@ class TestGMMOLS(object):
         assert_allclose(res1.bse * dffac, res2.HC0_se, rtol=5e-6, atol=0)
         assert_allclose(res1.bse * dffac, res2.HC0_se, rtol=0, atol=1e-7)
 
-
+    @pytest.mark.xfail(reason="Not asserting anything meaningful",
+                       raises=NotImplementedError, strict=True)
     def test_other(self):
         res1, res2 = self.res1, self.res2
-
+        raise NotImplementedError
 
 
 
@@ -215,13 +212,12 @@ class CheckGMM(object):
         assert_allclose(res1.bse * dffac, res2.bse, rtol=rtol, atol=0)
         assert_allclose(res1.bse * dffac, res2.bse, rtol=0, atol=atol)
 
-    #skip temporarily
-    def _est_other(self):
+    def test_other(self):
+        # TODO: separate Q and J tests
         res1, res2 = self.res1, self.res2
         assert_allclose(res1.q, res2.Q, rtol=5e-6, atol=0)
         assert_allclose(res1.jval, res2.J, rtol=5e-5, atol=0)
 
-
     def test_hypothesis(self):
         res1, res2 = self.res1, self.res2
         restriction = np.eye(len(res1.params))
@@ -355,13 +351,19 @@ class TestGMMStOnestep(CheckGMM):
         # TODO: next two produce the same as before (looks like)
         bse = np.sqrt(np.diag((res1._cov_params(has_optimal_weights=False))))
                                             #weights=res1.weights))))
-        # TODO: doesn't look different
+        # TODO: does not look different
         #assert_allclose(res1.bse, res2.bse, rtol=5e-06, atol=0)
         #nobs = instrument.shape[0]
         #w0inv = np.dot(instrument.T, instrument) / nobs
         q = self.res1.model.gmmobjective(self.res1.params, np.linalg.inv(self.res1.weights))
         #assert_allclose(q, res2.Q, rtol=5e-6, atol=0)
 
+    @pytest.mark.xfail(reason="q vs Q comparison fails",
+                       raises=AssertionError, strict=True)
+    def test_other(self):
+        super(TestGMMStOnestep, self).test_other()
+
+
 class TestGMMStOnestepNO(CheckGMM):
     # matches Stats's defaults wargs={'centered':False}, has_optimal_weights=False
 
@@ -385,6 +387,12 @@ class TestGMMStOnestepNO(CheckGMM):
         from .results_gmm_griliches import results_onestep as results
         cls.res2 = results
 
+    @pytest.mark.xfail(reason="q vs Q comparison fails",
+                       raises=AssertionError, strict=True)
+    def test_other(self):
+        super(TestGMMStOnestepNO, self).test_other()
+
+
 class TestGMMStOneiter(CheckGMM):
 
     @classmethod
@@ -407,6 +415,10 @@ class TestGMMStOneiter(CheckGMM):
         from .results_gmm_griliches import results_onestep as results
         cls.res2 = results
 
+    @pytest.mark.xfail(reason="q vs Q comparison fails",
+                       raises=AssertionError, strict=True)
+    def test_other(self):
+        super(TestGMMStOneiter, self).test_other()
 
     def test_bse_other(self):
         res1, res2 = self.res1, self.res2
@@ -417,13 +429,13 @@ class TestGMMStOneiter(CheckGMM):
         # TODO: next two produce the same as before (looks like)
         bse = np.sqrt(np.diag((res1._cov_params(has_optimal_weights=False,
                                             weights=res1.weights))))
-        # TODO: doesn't look different
+        # TODO: does not look different
         #assert_allclose(res1.bse, res2.bse, rtol=5e-06, atol=0)
         bse = np.sqrt(np.diag((res1._cov_params(has_optimal_weights=False))))
                                                 #use_weights=True #weights=w
         #assert_allclose(res1.bse, res2.bse, rtol=5e-06, atol=0)
 
-        #This doesn't replicate Stata oneway either
+        #This does not replicate Stata oneway either
         nobs = instrument.shape[0]
         w0inv = np.dot(instrument.T, instrument) / nobs
         q = self.res1.model.gmmobjective(self.res1.params, w)#self.res1.weights)
@@ -453,6 +465,11 @@ class TestGMMStOneiterNO(CheckGMM):
         from .results_gmm_griliches import results_onestep as results
         cls.res2 = results
 
+    @pytest.mark.xfail(reason="q vs Q comparison fails",
+                       raises=AssertionError, strict=True)
+    def test_other(self):
+        super(TestGMMStOneiterNO, self).test_other()
+
 
 #------------ Crosscheck subclasses
 
@@ -485,6 +502,11 @@ class TestGMMStOneiterNO_Linear(CheckGMM):
         from .results_gmm_griliches import results_onestep as results
         cls.res2 = results
 
+    @pytest.mark.xfail(reason="q vs Q comparison fails",
+                       raises=AssertionError, strict=True)
+    def test_other(self):
+        super(TestGMMStOneiterNO_Linear, self).test_other()
+
 
 class TestGMMStOneiterNO_Nonlinear(CheckGMM):
 
@@ -518,6 +540,10 @@ class TestGMMStOneiterNO_Nonlinear(CheckGMM):
         from .results_gmm_griliches import results_onestep as results
         cls.res2 = results
 
+    @pytest.mark.xfail(reason="q vs Q comparison fails",
+                       raises=AssertionError, strict=True)
+    def test_other(self):
+        super(TestGMMStOneiterNO_Nonlinear, self).test_other()
 
     def test_score(self):
         params = self.res1.params * 1.1
@@ -533,7 +559,6 @@ class TestGMMStOneiterNO_Nonlinear(CheckGMM):
         assert_allclose(sc1, np.zeros(len(params)), rtol=0, atol=1e-8)
 
 
-
 class TestGMMStOneiterOLS_Linear(CheckGMM):
 
     @classmethod
@@ -566,8 +591,13 @@ class TestGMMStOneiterOLS_Linear(CheckGMM):
         #cls.res2 = results
         cls.res2 = res_ols
 
+    @pytest.mark.xfail(reason="RegressionResults has no `Q` attribute",
+                       raises=AttributeError, strict=True)
+    def test_other(self):
+        super(TestGMMStOneiterOLS_Linear, self).test_other()
 
-#------------------
+
+# ------------------
 
 class TestGMMSt2(object):
     # this looks like an old version, trying out different comparisons
@@ -625,7 +655,7 @@ class TestGMMSt2(object):
 
         # TODO: resolve this
         # try bse from previous step, is closer to Stata
-        # guess: Stata ivreg2 doesn't calc for bse update after final iteration
+        # guess: Stata ivreg2 does not calc for bse update after final iteration
         # need better test case, bse difference is close to numerical optimization precision
         assert_allclose(self.res3.bse, res2.bse, rtol=5e-05, atol=0)
         assert_allclose(self.res3.bse, res2.bse, rtol=0, atol=5e-06)
